@@ -9,7 +9,7 @@ TODO: Add module docstring
 """
 
 from ipywidgets import DOMWidget
-from traitlets import Unicode, Int
+from traitlets import Unicode, Int, Float
 from ._frontend import module_name, module_version
 
 
@@ -23,11 +23,13 @@ class Player(DOMWidget):
     _view_module = Unicode(module_name).tag(sync=True)
     _view_module_version = Unicode(module_version).tag(sync=True)
 
-    _width = Int(480).tag(sync=True)
-    _height = Int(270).tag(sync=True)
+    _width = Int(0).tag(sync=True)
+    _height = Int(0).tag(sync=True)
+    _aspect_ratio = Float(1.78).tag(sync=True)
     value = Unicode('').tag(sync=True)
-    def __init__(self, vid, width=480, height=270):
+    def __init__(self, vid, width=0, height=0, aspect_ratio=1.78):
         DOMWidget.__init__(self)
         self._width = width
         self._height = height
+        self._aspect_ratio = aspect_ratio
         self.value = vid
