@@ -155,7 +155,7 @@ export
       wrapper0.style.paddingTop = `${1/aspectRatio*100}%`;
       wrapper0.appendChild(wrapper);
       const wrapper1 = document.createElement('div');
-      wrapper1.style.maxWidth = '720px';
+      wrapper1.style.maxWidth = '1280px';
       wrapper1.style.minWidth = '360px';
       wrapper1.appendChild(wrapper0);
       this.el.appendChild(wrapper1);
@@ -205,9 +205,12 @@ export
               type: window.AliPlayerComponent.QualityComponent,
             },
           ],
-        }, () => {
+        }, (player: any) => {
             // 恢复
             // window.define = window.__define;
+            if (typeof window.__ipyaliplayer_on_get_instance === 'function') {
+              window.__ipyaliplayer_on_get_instance(player);
+            }
           }
         );
       }).catch(e => {
